# -*- coding: utf-8 -*-

from simmate.database.base_data_types import DensityofStatesCalc


class MatprojDensityOfStates(DensityofStatesCalc):
    pass
